@@ -28,7 +28,6 @@ help_schema = {
     "type": "dict",
 }
 
-
 parameter_field_schema = {
     "help": help_schema.copy(),
     "collapsed": {"required": False, "type": "boolean"},
@@ -62,11 +61,14 @@ parameter_field_schema = {
             {"forbidden": ["connection", "code", "sql", "enum", "enum_list"]},
         ],
     },
+    "shared_config_type_uuid": {"type": "string", "required": False},
+    "shared_field_type_uuid": {"type": "string", "required": False},
     "shared_object_type_uuid": {"type": "string", "required": False},
     "max": {"required": False, "type": "integer"},
     "min": {"required": False, "type": "integer"},
     "default": {"required": False},
 }
+
 parameter_group_schema = {
     "display_name": {"type": "string", "required": True},
     "collapsed": {"required": False, "type": "boolean",},
@@ -84,7 +86,6 @@ parameter_group_schema = {
     },
 }
 
-
 engine_schema = {
     "uuid": {
         "type": "string",
@@ -135,36 +136,43 @@ engine_schema = {
 }
 
 
-shared_object_type_schema = {
-    "uuid": {
-        "type": "string",
-        "minlength": 8,
-        "required": True,
-        "regex": r"^[A-Z\d]+-[A-Z\d]+$",
-    },
-    "alias": {"type": "string", "required": True},
-    "description": {"type": "string", "required": True},
-    "nnd_model_version": {"type": "integer", "required": True},
-    "categories": {
-        "type": "list",
-        "required": True,
-        "schema": {
-            "type": "dict",
-            "schema": {"name": {"type": "string", "required": True}},
+def _get_shared_type_schema(name):
+    return {
+        "uuid": {
+            "type": "string",
+            "minlength": 8,
+            "required": True,
+            "regex": r"^[A-Z\d]+-[A-Z\d]+$",
         },
-    },
-    "type": {"allowed": ["shared_object_type"], "required": True},
-    "parameters": {
-        "type": "list",
-        "schema": {
-            "type": "dict",
-            "anyof_schema": [
-                parameter_field_schema.copy(),
-                parameter_group_schema.copy(),
-            ],
+        "alias": {"type": "string", "required": True},
+        "description": {"type": "string", "required": True},
+        "nnd_model_version": {"type": "integer", "required": True},
+        "categories": {
+            "type": "list",
+            "required": True,
+            "schema": {
+                "type": "dict",
+                "schema": {"name": {"type": "string", "required": True}},
+            },
         },
-    },
-}
+        "type": {"allowed": [name], "required": True},
+        "parameters": {
+            "type": "list",
+            "schema": {
+                "type": "dict",
+                "anyof_schema": [
+                    parameter_field_schema.copy(),
+                    parameter_group_schema.copy(),
+                ],
+            },
+        },
+    }
+
+
+shared_config_type_schema = _get_shared_type_schema("shared_config_type")
+shared_field_type_schema = _get_shared_type_schema("shared_field_type")
+shared_object_type_schema = _get_shared_type_schema("shared_object_type")
+
 connection_type_schema = {
     "uuid": {
         "type": "string",
@@ -189,8 +197,11 @@ connection_type_schema = {
         "schema": {"type": "dict", "schema": parameter_group_schema.copy()},
     },
 }
+
 schemas = {
     "engine": engine_schema,
+    "shared_config_type": shared_config_type_schema,
+    "shared_field_type": shared_field_type_schema,
     "shared_object_type": shared_object_type_schema,
     "connection": connection_type_schema,
 }
